@@ -122,6 +122,9 @@ def diffRecursive(dir1, dir2):
         ):
             continue
 
+        if "scons-debug" in filename:
+            continue
+
         if not os.path.exists(path2):
             test_logger.warning("Only in %s: %s" % (dir1, filename))
             result = False
@@ -192,7 +195,12 @@ def executePASS1():
         source_dir = os.path.join(base_dir, package)
         target_dir = package
 
-        removeDirectory(path=target_dir, ignore_errors=False)
+        removeDirectory(
+            path=target_dir,
+            logger=test_logger,
+            ignore_errors=False,
+            extra_recommendation=None,
+        )
 
         os.mkdir(target_dir)
 
@@ -322,7 +330,12 @@ def compileAndCompareWith(nuitka, pass_number):
 
                 target_dir = os.path.join(tmp_dir, target)
 
-                removeDirectory(path=target_dir, ignore_errors=False)
+                removeDirectory(
+                    logger=test_logger,
+                    path=target_dir,
+                    ignore_errors=False,
+                    extra_recommendation=None,
+                )
 
                 command = [
                     nuitka,
